package main

import (
	"log"
	"time"
)

func main() {
	// Load configuration
	config := loadConfig("config.json")

	notifier := NtfyNotifier{Topic: config.NtfyTopic}

	// Main loop
	for {
		for _, repo := range config.Repos {
			tag, err := repo.GetLatestTag()
			if err != nil {
				log.Printf("Failed to get latest tag for %s: %v", repo.Repo, err)
				continue
			}
			if tag.Name == "" {
				log.Printf("No tags found for %s", repo.Repo)
				continue
			}
			if notifier.Notify(repo, tag.Name) {
				log.Printf("Notified for %s/%s: %s", repo.Owner, repo.Repo, tag.Name)
			}
		}
		time.Sleep(time.Duration(config.Interval) * time.Second)
	}
}
